#include <stdio.h>

#include "segy_reel.h"
#include "externals.h"

/************************************************************************/
/*  read_segy_reel:							*/
/*	Read SEGY reel headers.  Fill in binary reel header.		*/
/*  return:								*/
/*	Number of traces in file (1 if no reel header).			*/
/************************************************************************/
int read_segy_reel 
   (FILE	*input,
    SEGYBREELHEAD **pbin_reel_header,
    int		segy_fmt)
{
    SEGYDREELHEAD char_reel_header;
    SEGYBREELHEAD *bin_reel_header;
    int ntraces;

    *pbin_reel_header = NULL;
    bin_reel_header = (SEGYBREELHEAD *)malloc(sizeof(SEGYBREELHEAD));
    switch (segy_fmt) {
      case BERKELEY_FORMAT:
	/* Skip the text descriptive reel header record.			*/
	if (fread(&char_reel_header,1,sizeof(SEGYDREELHEAD),input)!=sizeof(SEGYDREELHEAD)) {
	    fprintf(stderr, "Error reading in a SEG-Y Descriptive reel header.\n");
	    exit(1);
	}
	/* Read the binary reel header.					*/
	if (fread(bin_reel_header,1,sizeof(SEGYBREELHEAD),input)!=sizeof(SEGYBREELHEAD)) {
	    fprintf(stderr, "Error reading in a SEG-Y Binary reel header.\n");
	    exit(1);
	}
	ntraces = bin_reel_header->kntr;
	break;
      case PASSCAL_FORMAT:
	memset((void *)bin_reel_header, 0, sizeof(SEGYBREELHEAD));
	ntraces = 1;
	break;
      default:
	fprintf (stderr, "Invalid segy format: %d\n", segy_fmt);
	exit(1);
	break;
    }
    *pbin_reel_header = bin_reel_header;
    return (ntraces);
}
