.\$Id: segy2ms.man,v 1.1 1999/04/07 17:48:00 doug Exp $ 
.TH SEGY2MS 1 "12 November 1996" BDSN
.SH NAME
segy2ms - Convert SEGY data file to MiniSEED data file.
.SH SYNOPSIS
.B segy2ms 
[\fB\-S\fR\ \fIstation_id\fR]
[\fB\-C\fR\ \fIchannel_id\fR]
[\fB\-N\fR\ \fInetwork_id\fR]
[\fB\-f\ Berkeley|PASSCAL\fR]
[\fB\-b\ \fIblksize\fR]
[\fB\-F\ \fIformat\fR]
[\fB\-m\ \fIchannel_map_file\fR]
[\fB\-o\ \fIoutput_file\fR]
d[\fB\-h\fR]
[\fIinput_files...\fR
.br
.SH DESCRIPTION
The program
.B segy2ms
converts a SEGY data file to a MiniSEED file with user-specifiable MiniSEED
data format and blocksize.  The program will read 2 variants of SEGY data
files:  UC Berkeley/LBL and PASSCAL SEGY files.  UC Berkeley/LBL SEGY files
contain both the printable and binary SEGY reel headers and 1 or more SEGY
data traces Each data trace contains consists of a SEGY trace header followed
by trace data.  PASSCAL SEGY files contain or more more SEGY data traces,
where each trace consists of a trace header followed by trace data.  PASSCAL
SEGY data files do not contain any SEGY reel header.
.SH OPTIONS
.TP
.BI \-S\  station_id
explicitly specified the SEED station name.  This option overrides
any station name derived from the SEGY file or the station and
channel remapping specified by the channel_map file.
This option should NOT be used for SEGY files that contain data from
multiple stations.
.TP
.BI \-C\  channel_id
explicitly specified the SEED channel name.  This option overrides
any channel name derived from the SEGY file or the station and
channel remapping specified by the channel_map file.
This option should NOT be used for SEGY files that contain data from
multiple channels.
.TP
.BI \-N\  network_id
explicitly specified the SEED network name.  If this option is not
specified, the program will use the default network name that was compiled
into the program.
.TP
.B \-f Berkeley | PASSCAL
specifies that the input data is either in UC Berkeley/LBL SEGY format or
PASSCAL SEGY format The default is to assume that the input is in UC
Berkeley/LBL SEGY format.  The format name may be appreviated to a single
character.
.TP
.B \-b blksize
specifies the MiniSEED record size for the output MiniSEED file.
The default record size is 4K.
.TP
.B \-F format
specifies the MiniSEED data format for the output MiniSEED file.
Valid formats are STEIM1, STEIM1, INT16, INT24, and INT32.
The default format is STEIM1.
.TP
.B \-m channel_map_file
specifies an optional file that contains information for mapping SEGY
station and channel names to SEED station and channel names.  If this option
is not used, SEED station and channel information is derived from the
station and channel name of each SEGY trace.
.TP
.B \-F format
specifies the MiniSEED data format for the output MiniSEED file.
Valid formats are STEIM1, STEIM1, INT16, INT24, and INT32.
The default format is STEIM1.
.TP
.B \-h
print out a simple help message with syntax and explaination of the options.
.TP
\fIinput_files\fR
.br
specifies a list of SEGY files to be read.  If no input file is specified, 
data is read from stdin.
.TP
\fIoutput_file\fR
.br
specifies the output file to be written.  If no output file is specified, 
data is written to stdout.
.SH NOTES
If only one filename is specified, it is assumed to be the input file.  You
cannot specify an output filename when the input is read from stdin.  You
can instead use the shell i/o redirection to specify the output file.

The SEGY to MiniSEED station and channel mapping file consists of
lines with 4 token which represent the SEGY station and channel and
the replacement MiniSEED station and channel name.  Wildcard charaters
may be used in the SEGY names, and a "*" in the MiniSEED name
signifies that the corresponding SEGY name should be used for the
SEED name.  Note that all matching is case-dependent.
A sample station and channel mapping file is include for reference.
.sp
.nf 
##################################################
# Station and Channel mapping file
# for Parkfield SEGY data.
#
# If a SEGY station and channel entry match 
# the table entry for SEGY station and channel 
# (using wildcard matching), use the corresponding
#  SEED station and channel table entries
# as the SEED station and channel name.
#
# 1.  A "*" in a SEED field means use the SEGY value.
# 2.  A "" designates an empty (0 length) field.
#
# Any mapping with resulsts in an empty SEED station 
# and channel name will cause that channel to be delete.
#
# Once a successful mapping has been made for a SEGY 
# station and channel, terminate the mapping.
#
# SEGY	SEGY	SEED	SEED	Comments
# Stat	Chan	Stat	Channel
##################################################
*	z	*	CLZ	# Map SEGY channel z
*	1	*	CL1	# Map SEGY channel 1
*	2	*	CL2	# Map SEGY channel 2
-	*	""	""	# Delete channel "-".
TC	""	*	CLZ	# Supply channel name for TC
*	""	*	XXX	# Supply default channel name.
.ad

.SH UC BERKELEY/LBL EXTENSIONS
.TP 
SEGY reel header extensions The UC Berkeley/LBL SEGY format contains the
following variables in the first unused space (starting at offset 60) in the
SEGY binary reel header.
.fo
    /* Additional unused elements used by LBL. */
    short int	nyear;	/* year		*/
    short int	nday;	/* day of year	*/
    short int	nhour;	/* hour		*/
    short int	nmin;	/* minute	*/
    short int	nsec;	/* second	*/
    short int	nmsec;	/* millisecond	*/
.fi
.br
The time provides a common start time for the first data point of each
trace in the file.
.TP
SEGY trace header extensions
.br
The Berkeley/LBL SEGY format also places the station name in the first
unused field (offset 180) in the trace header.  However, the station name
may start either at offset 180 (station_name[0]) or offset 182
(station_name[2]), depending on the version of the file.  If the first 2
characters are NULL, assume the name starts at offset 182 (station_name[2]).
The station name is assumed the be the first 3 non-null characters, followed
immediately by the channel name (often 1 character).  The channel name may
NULL.

.SH PASSCAL Extensions
The PASSCAL SEGY format contains neither the SEGY printable reel header
(3200 bytes) nor the SEGY binary reel header (400 bytes).  All trace
information is contained in the trace header.  Additional unused fields
(starting at offset 180) in the trace header are used for PASSCAL related
variable.
.nf
   /* PASSCAL additional fields used in trace header.		    */
   char  station_name[6];   /* 180 Station Name code (5 chars + \0) */
   char  sensor_serial[8];  /* 186 Sensor Serial code (7 chars + \0) */
   char  channel_name[4];   /* 194 Channel Name code (3 chars + \0) */
   short totalStaticHi;     /* 198 Total Static in MILLISECS added to */
                            /*Trace Start Time (high 2 bytes)*/
   long  samp_rate;         /* 200 Sample interval in MICROSECS as a 32 bit integer */
   short data_form;         /* 204 Data Format flag: 0=16 bit, 1=32 bit integer */
   short m_secs;            /* 206 MILLISECONDS of seconds of Start of trace */
   short trigyear;          /* 208 year of Trigger time */
   short trigday;           /* 210 day of year at Trigger time */
   short trighour;          /* 212 hour of day at Trigger time */
   short trigminute;        /* 214 minute of hour at Trigger time */
   short trigsecond;        /* 216 second of minute at Trigger time */
   short trigmills;         /* 218 MILLISECONDS of seconds of Trigger time */
   float scale_fac;         /* 220 Scale Factor (IEEE 32 bit float) */
   short inst_no;           /* 224 Instrument Serial Number */
   short not_to_be_used;    /* 226 X */
   long  num_samps;         /* 228 Number of Samples as a 32 bit integer
                             * (when sampleLength == 32767) */
   long  max;               /* 232 Maximum value in Counts */
   long  min;               /* 236 Minimum value in Counts */
.fi
.br
.TP
SEED Station and Channel names
.br 
The SEED station name is derived from the
PASSCAL inst_no as a 5-digit zero filled string, and the SEED channel name
is derived from the standard trace header field channel_number as a 3-digit
zero filled string.

.TP 
sample interval
.br
The sampling interval is taken from the standard trace header variable
deltaSample (offset 116) unless that value is 1, in which case the sample
sample interval is taken from the PASSCAL variable samp_rate.

.TP
number of samples
.br
The number of samples is taken from the standard trace header variable
sampleLength (offset 114) unless that value is 32767, in which case number of
samples is taken from the PASSCAL variable num_samps.

.TP 
start time of trace
.br
The start time of trace is taken from the year, day, hour, minute, and second
variables (starting at offset 156), and the millisecond time is taken from the
PASSCAL variable m_secs.

.SH AUTHOR
Douglas Neuhauser, UC Berkeley Seismographic Station, 
doug@seismo.berkeley.edu

